@@ -32,6 +32,8 @@
 #include <attica/provider.h>
 #include <attica/providermanager.h>
 
+#include <QDebug>
+#include <KDebug>
 #include <KIO/Job>
 
 #include <plasma/datacontainer.h>
@@ -53,7 +55,7 @@ OcsEngine::OcsEngine(QObject* parent, const QVariantList& args)
             this, SLOT(networkStatusChanged(Solid::Networking::Status)));
 
     m_pm.setAuthenticationSuppressed(true);
-    connect(&m_pm, SIGNAL(providerAdded(const Attica::Provider&)), SLOT(providerAdded(const Attica::Provider&)));
+    connect(&m_pm, SIGNAL(providerAdded(Attica::Provider)), SLOT(providerAdded(Attica::Provider)));
     m_pm.loadDefaultProviders();
     connect(m_serviceUpdates.data(), SIGNAL(mapped(QString)), SLOT(serviceUpdates(QString)));
 }
