@@ -20,48 +20,34 @@
 #ifndef RTM_AUTH_H
 #define RTM_AUTH_H
 
-#include <QString>
-#include <QObject>
-#include <QHash>
-#include <QBuffer>
-#include <QNetworkReply>
-
-#include <KParts/BrowserExtension>
-
 #include "request.h"
 
-class QWebView;
-
-
 namespace RTM {
 
-class RTM_EXPORT Auth : public Request
+class AuthPrivate;
+
+class Auth : public Request
 {
 Q_OBJECT
   public:
     Auth(RTM::Permissions permissions, const QString &apiKey, const QString &sharedSecret);
-    void showLoginWebpage();
     QString getAuthUrl();
     void continueAuthForToken();
 
     ~Auth();
   protected:
     QString getTextPermissions(RTM::Permissions permissions);
-    QString requestUrl();
-    QString frob;
-    QString apiKey;
-    Request *frobRequest;
-    Request *tokenRequest;
 
   signals:
     void authUrlReady(QString authUrl);
     void tokenReceived(QString token);
 
   protected slots:
-    void pageClosed();
-    void showLoginWindowInternal(RTM::Request* rawReply);
+    void onFrobRequestFinished(RTM::Request* reply);
 public slots:
     void tokenResponse(RTM::Request*);
+  private:
+    AuthPrivate * const d;
 };
 
 } // Namespace RTM
